@@ -10,7 +10,7 @@ use strict;
 use warnings;
 our ( %Config, $VERSION );
 
-$VERSION = "5.038004";
+$VERSION = "5.040003";
 
 # Skip @Config::EXPORT because it only contains %Config, which we special
 # case below as it's not a function. @Config::EXPORT won't change in the
@@ -56,11 +56,11 @@ sub import {
     return;
 }
 
-die "$0: Perl lib version (5.38.4) doesn't match executable '$^X' version ($])"
+die "$0: Perl lib version (5.40.3) doesn't match executable '$^X' version ($])"
     unless $^V;
 
-$^V eq 5.38.4
-    or die sprintf "%s: Perl lib version (5.38.4) doesn't match executable '$^X' version (%vd)", $0, $^V;
+$^V eq 5.40.3
+    or die sprintf "%s: Perl lib version (5.40.3) doesn't match executable '$^X' version (%vd)", $0, $^V;
 
 
 sub FETCH {
@@ -85,27 +85,27 @@ sub AUTOLOAD {
 # tie returns the object, so the value returned to require will be true.
 tie %Config, 'Config', {
     archlibexp => '/usr/lib/perl5/core_perl',
-    archname => 'x86_64-cygwin-thread-multi',
-    cc => 'gcc',
-    d_readlink => undef,
+    archname => 'x86_64-linux-thread-multi',
+    cc => 'cc',
+    d_readlink => 'define',
     d_symlink => 'define',
-    dlext => 'dll',
+    dlext => 'so',
     dlsrc => 'dl_dlopen.xs',
     dont_use_nlink => undef,
-    exe_ext => '.exe',
+    exe_ext => '',
     inc_version_list => ' ',
     intsize => '4',
-    ldlibpthname => 'PATH',
-    libpth => '/usr/lib',
-    osname => 'cygwin',
-    osvers => '3.6.1-0cfedd4f.x86_64',
+    ldlibpthname => 'LD_LIBRARY_PATH',
+    libpth => '/usr/local/lib /usr/lib /lib',
+    osname => 'linux',
+    osvers => '6.16.0-1-next',
     path_sep => ':',
     privlibexp => '/usr/share/perl5/core_perl',
     scriptdir => '/usr/bin/core_perl',
     sitearchexp => '/usr/lib/perl5/site_perl',
     sitelibexp => '/usr/share/perl5/site_perl',
-    so => 'dll',
+    so => 'so',
     useithreads => 'define',
     usevendorprefix => 'define',
-    version => '5.38.4',
+    version => '5.40.3',
 };
